/*
** Copyright (C) 2002-2003 Ryan McCabe <ryan@numb.org>
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License, version 2,
** as published by the Free Software Foundation.
*/

#include <unistd.h>
#include <stdio.h>
#include <fcntl.h>
#include <string.h>
#include <sys/types.h>
#include <sys/stat.h>

#include <snuff.h>
#include <snuff_mta.h>

#define ALIAS_FILE "/var/qmail/alias/.qmail-ojnk-"

int add_mta_alias(char *alias, char *username) {
	int fd;
	char filename[MAX_USERLEN + sizeof(ALIAS_FILE)];
	size_t str_len;

	if (alias == NULL || username == NULL)
		return (-1);

	snprintf(filename, sizeof(filename), "%s%s", ALIAS_FILE, alias);

	fd = open(filename, O_WRONLY | O_CREAT | O_EXCL, 0644);
	if (fd == -1)
		return (-1);

	str_len = strlen(username);
	if (write(fd, username, str_len) != (ssize_t) str_len)
		goto err_out;

	if (write(fd, "\n", 1) != 1)
		goto err_out;

	close(fd);
	return (0);

err_out:
	close(fd);
	unlink(filename);
	return (-1);
}

int check_mta_alias(char *alias) {
	char filename[MAX_USERLEN + sizeof(ALIAS_FILE)];
	struct stat st;

	snprintf(filename, sizeof(filename), "%s%s", ALIAS_FILE, alias);

	return (stat(filename, &st));
}

int del_mta_alias(char *alias) {
	char filename[MAX_USERLEN + sizeof(ALIAS_FILE)];

	snprintf(filename, sizeof(filename), "%s%s", ALIAS_FILE, alias);

	return (unlink(filename));
}
